==> plugin-center-api-1.0.19-20181022.101608-2-sources.jar: cn/com/duiba/plugin/center/api/request/PlaceOrderByItemRequest.java <==
package cn.com.duiba.plugin.center.api.request;

import cn.com.duiba.biz.tool.duiba.dto.RequestParams;
import cn.com.duiba.plugin.center.api.enums.PlaceOrderApiEnum;

/**
 * Created by hww on 2018/9/28 下午3:16.
 */
public class PlaceOrderByItemRequest implements PlaceOrderRequest {

    private static final long serialVersionUID = 8753802031584428880L;

    /** 应用id 必传 */
    private Long appId;
    /** 兑吧用户id 必传 */
    private Long consumerId;
    /** 开发者用户id 必传 */
    private String partnerUserId;
    /** 兑吧商品id 必传 */
    private Long itemId;
    /** 兑吧商品类型 必传 */
    private String itemType;
    /** 奖项名形成 非必传 */
    private String prizeName;
    /** 奖品面值 非必传   直冲类、开发者虚拟商品等必传 */
    private String facePrice;
    /** RequestParams.parse()方法解析request  非必传 */
    private RequestParams requestParams;

    public Long getAppId() {
        return appId;
    }

    public void setAppId(Long appId) {
        this.appId = appId;
    }

    public Long getConsumerId() {
        return consumerId;
    }

    public void setConsumerId(Long consumerId) {
        this.consumerId = consumerId;
    }

    public String getPartnerUserId() {
        return partnerUserId;
    }

    public void setPartnerUserId(String partnerUserId) {
        this.partnerUserId = partnerUserId;
    }

    public Long getItemId() {
        return itemId;
    }

    public void setItemId(Long itemId) {
        this.itemId = itemId;
    }

    public String getItemType() {
        return itemType;
    }

    public void setItemType(String itemType) {
        this.itemType = itemType;
    }

    public String getPrizeName() {
        return prizeName;
    }

    public void setPrizeName(String prizeName) {
        this.prizeName = prizeName;
    }

    public String getFacePrice() {
        return facePrice;
    }

    public void setFacePrice(String facePrice) {
        this.facePrice = facePrice;
    }

    public RequestParams getRequestParams() {
        return requestParams;
    }

    public void setRequestParams(RequestParams requestParams) {
        this.requestParams = requestParams;
    }

    @Override
    public String getApiMethodName() {
        return PlaceOrderApiEnum.PLACE_ITEM.name();
    }
}

==> plugin-center-api-1.1.8-sources.jar: cn/com/duiba/plugin/center/api/request/PlaceOrderByItemRequest.java <==
package cn.com.duiba.plugin.center.api.request;

import cn.com.duiba.biz.tool.duiba.dto.RequestParams;
import cn.com.duiba.plugin.center.api.enums.PlaceOrderApiEnum;

/**
 * Created by hww on 2018/9/28 下午3:16.
 */
public class PlaceOrderByItemRequest implements PlaceOrderRequest {

    private static final long serialVersionUID = 8753802031584428880L;

    /** 应用id 必传 */
    private Long appId;
    /** 兑吧用户id 必传 */
    private Long consumerId;
    /** 开发者用户id 必传 */
    private String partnerUserId;
    /** 兑吧商品id 必传1/2 */
    private Long itemId;
    /** 开发者商品id 必传1/2 */
    private Long appItemId;
    /** 兑吧商品类型 必传 */
    private String itemType;
    /** 奖项名形成 非必传 */
    private String prizeName;
    /** 奖品面值 非必传   直冲类、开发者虚拟商品等必传 */
    private String facePrice;
    /** RequestParams.parse()方法解析request  非必传 */
    private RequestParams requestParams;

    public Long getAppId() {
        return appId;
    }

    public void setAppId(Long appId) {
        this.appId = appId;
    }

    public Long getConsumerId() {
        return consumerId;
    }

    public void setConsumerId(Long consumerId) {
        this.consumerId = consumerId;
    }

    public String getPartnerUserId() {
        return partnerUserId;
    }

    public void setPartnerUserId(String partnerUserId) {
        this.partnerUserId = partnerUserId;
    }

    public Long getItemId() {
        return itemId;
    }

    public void setItemId(Long itemId) {
        this.itemId = itemId;
    }

    public String getItemType() {
        return itemType;
    }

    public void setItemType(String itemType) {
        this.itemType = itemType;
    }

    public String getPrizeName() {
        return prizeName;
    }

    public void setPrizeName(String prizeName) {
        this.prizeName = prizeName;
    }

    public String getFacePrice() {
        return facePrice;
    }

    public void setFacePrice(String facePrice) {
        this.facePrice = facePrice;
    }

    public RequestParams getRequestParams() {
        return requestParams;
    }

    public void setRequestParams(RequestParams requestParams) {
        this.requestParams = requestParams;
    }

    public Long getAppItemId() {
        return appItemId;
    }

    public void setAppItemId(Long appItemId) {
        this.appItemId = appItemId;
    }

    @Override
    public String getApiMethodName() {
        return PlaceOrderApiEnum.PLACE_ITEM.name();
    }
}
